"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RDSClient_1 = require("../../RDSClient");
const DescribeDBEngineVersionsCommand_1 = require("../../commands/DescribeDBEngineVersionsCommand");
const DescribeDBInstancesCommand_1 = require("../../commands/DescribeDBInstancesCommand");
async function smokeTestRunner() {
    const defaultRegion = process.env.AWS_SMOKE_TEST_REGION || "us-west-2";
    let testFailed = false;
    console.log("1..2");
    console.log("# Running tests for RDS.");
    await (async () => {
        const client = new RDSClient_1.RDSClient({
            region: defaultRegion
        });
        const command = new DescribeDBEngineVersionsCommand_1.DescribeDBEngineVersionsCommand({});
        try {
            const result = await client.send(command);
            console.log("ok RDS DescribeDBEngineVersions - no error expected from service");
        }
        catch (err) {
            console.log("not ok RDS DescribeDBEngineVersions - no error expected from service");
            // output unexpected error information
            console.log("# " + err.message);
            err.stack.split("\n").forEach((line) => {
                console.log("# " + line);
            });
            testFailed = true;
        }
    })();
    await (async () => {
        const client = new RDSClient_1.RDSClient({
            region: defaultRegion
        });
        const command = new DescribeDBInstancesCommand_1.DescribeDBInstancesCommand({
            DBInstanceIdentifier: "fake-id"
        });
        try {
            const result = await client.send(command);
            console.log("not ok RDS DescribeDBInstances - error expected from service");
            testFailed = true;
        }
        catch (err) {
            console.log("ok RDS DescribeDBInstances - error expected from service");
        }
    })();
    if (testFailed) {
        process.exit(1);
    }
    else {
        process.exit(0);
    }
}
// execute the test runner
smokeTestRunner();
//# sourceMappingURL=index.spec.js.map