import { _RecurringCharge, _UnmarshalledRecurringCharge } from "./_RecurringCharge";
/**
 * <p> This data type is used as a response element in the <code>DescribeReservedDBInstances</code> and <code>PurchaseReservedDBInstancesOffering</code> actions. </p>
 */
export interface _ReservedDBInstance {
    /**
     * <p>The unique identifier for the reservation.</p>
     */
    ReservedDBInstanceId?: string;
    /**
     * <p>The offering identifier.</p>
     */
    ReservedDBInstancesOfferingId?: string;
    /**
     * <p>The DB instance class for the reserved DB instance.</p>
     */
    DBInstanceClass?: string;
    /**
     * <p>The time the reservation started.</p>
     */
    StartTime?: Date | string | number;
    /**
     * <p>The duration of the reservation in seconds.</p>
     */
    Duration?: number;
    /**
     * <p>The fixed price charged for this reserved DB instance.</p>
     */
    FixedPrice?: number;
    /**
     * <p>The hourly price charged for this reserved DB instance.</p>
     */
    UsagePrice?: number;
    /**
     * <p>The currency code for the reserved DB instance.</p>
     */
    CurrencyCode?: string;
    /**
     * <p>The number of reserved DB instances.</p>
     */
    DBInstanceCount?: number;
    /**
     * <p>The description of the reserved DB instance.</p>
     */
    ProductDescription?: string;
    /**
     * <p>The offering type of this reserved DB instance.</p>
     */
    OfferingType?: string;
    /**
     * <p>Indicates if the reservation applies to Multi-AZ deployments.</p>
     */
    MultiAZ?: boolean;
    /**
     * <p>The state of the reserved DB instance.</p>
     */
    State?: string;
    /**
     * <p>The recurring price charged to run this reserved DB instance.</p>
     */
    RecurringCharges?: Array<_RecurringCharge> | Iterable<_RecurringCharge>;
    /**
     * <p>The Amazon Resource Name (ARN) for the reserved DB instance.</p>
     */
    ReservedDBInstanceArn?: string;
}
export interface _UnmarshalledReservedDBInstance extends _ReservedDBInstance {
    /**
     * <p>The time the reservation started.</p>
     */
    StartTime?: Date;
    /**
     * <p>The recurring price charged to run this reserved DB instance.</p>
     */
    RecurringCharges?: Array<_UnmarshalledRecurringCharge>;
}
